@@ -203,14 +203,14 @@ class RpcExchangerClient:
         if chat in self._chat_list:
             raise ChatAlreadyJoinedError()
 
-    async def send(self, msg: str, chat: int) -> None:
+    async def send(self, msg: str, chat: int, session: str | None) -> None:
         self.check_authorized()
         self.check_joined(chat)
-        if self._username is None:
-            raise NotAuthorizedError()
+        if session not in self._session_list:
+            raise ChatNotJoinedError()
         if not await self._rpc.chat.check_send(chat_id=chat, user_id=self._uid):
             raise PermissionDeniedError()
-        await self._exchanger.send_msg(self._username, msg, chat)    
+        await self._exchanger.send_msg(cast(str, self._username), msg, chat, session)    
     
     async def recv(self) -> tuple[Literal["message"], str, str, int, str | None] | tuple[Literal["event"], Event, Any, int]:
         raw_message: Any = None
